# -*- coding: utf-8 -*-
"""
     时间 : 2021-05-28 15:04
     作者 : 胡桓
     文件名 : setup.py
     邮箱: 1641143982@qq.com
"""
import setuptools

LICENSE = "MIT"
with open("README.md", "r",encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="testneo",
    version="0.1.3",
    author="胡桓",
    author_email='1641143982@qq.com',
    description='testneo自动化测试平台',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/neo19850910/testneo',
    packages=setuptools.find_packages(),
    license=LICENSE,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    zip_safe=True,
)
